==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebFormDataEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataDescriptionMetadata } from "./WebFormDataDescriptionMetadata";
import { WebFormDataEventArgsDescription } from "./WebFormDataEventArgsDescription";
/**
 * @hidden
 */
var WebFormDataEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFormDataEventArgsDescriptionMetadata, _super);
    function WebFormDataEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFormDataEventArgsDescriptionMetadata.b = function (a) {
        if (WebFormDataEventArgsDescriptionMetadata.a == null) {
            WebFormDataEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFormDataEventArgsDescriptionMetadata.c(WebFormDataEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebFormDataEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebFormDataEventArgsDescriptionMetadata.a);
        WebFormDataDescriptionMetadata.d(a);
    };
    WebFormDataEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FormDataEventArgs");
        a.item("Detail", "ExportedType:WebFormData");
    };
    WebFormDataEventArgsDescriptionMetadata.d = function (a) {
        WebFormDataEventArgsDescriptionMetadata.b(a);
        a.u("WebFormDataEventArgs", function () { return new WebFormDataEventArgsDescription(); });
        a.t("WebFormDataEventArgs", WebFormDataEventArgsDescriptionMetadata.a);
    };
    WebFormDataEventArgsDescriptionMetadata.$t = markType(WebFormDataEventArgsDescriptionMetadata, 'WebFormDataEventArgsDescriptionMetadata');
    WebFormDataEventArgsDescriptionMetadata.a = null;
    return WebFormDataEventArgsDescriptionMetadata;
}(Base));
export { WebFormDataEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebFormDataEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataDescriptionMetadata } from "./WebFormDataDescriptionMetadata";
import { WebFormDataEventArgsDescription } from "./WebFormDataEventArgsDescription";
/**
 * @hidden
 */
var WebFormDataEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFormDataEventArgsDescriptionMetadata, _super);
    function WebFormDataEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFormDataEventArgsDescriptionMetadata.b = function (a) {
        if (WebFormDataEventArgsDescriptionMetadata.a == null) {
            WebFormDataEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFormDataEventArgsDescriptionMetadata.c(WebFormDataEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebFormDataEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFormDataEventArgsDescriptionMetadata.a);
        WebFormDataDescriptionMetadata.d(a);
    };
    WebFormDataEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FormDataEventArgs");
        a.item("Detail", "ExportedType:WebFormData");
    };
    WebFormDataEventArgsDescriptionMetadata.d = function (a) {
        WebFormDataEventArgsDescriptionMetadata.b(a);
        a.aa("WebFormDataEventArgs", function () { return new WebFormDataEventArgsDescription(); });
        a.z("WebFormDataEventArgs", WebFormDataEventArgsDescriptionMetadata.a);
    };
    WebFormDataEventArgsDescriptionMetadata.$t = markType(WebFormDataEventArgsDescriptionMetadata, 'WebFormDataEventArgsDescriptionMetadata');
    WebFormDataEventArgsDescriptionMetadata.a = null;
    return WebFormDataEventArgsDescriptionMetadata;
}(Base));
export { WebFormDataEventArgsDescriptionMetadata };
